from .asset_invest import *
from .boom_index import *
from .cpi import *
from .currency_supply import *
from .customs import *
from .deposit_rate import *
from .deposit_reserve import *
from .faith_index import *
from .fdi import *
from .forex_deposit import *
from .forex_loan import *
from .gdp import *
from .gold_currency import *
from .goodes_index import *
from .gov_income import *
from .hose_index import *
from .imp_intrestraten import *
from .indus_grow import *
from .lpr import *
from .new_loan import *
from .oil_price import *
from .pmi import *
from .ppi import *
from .stock_open import *
from .stock_statistics import *
from .tax import *
from .total_retail import *
from .transfer_fund import *

from .index import *

# https://data.eastmoney.com/center/macro.html
