__all__ = [
    "headers",
    "trading_technicals_mapping",
]

headers = {
    'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.131 Safari/537.36',
}

trading_technicals_mapping = {
    "1min": "https://scanner.tradingview.com/symbol?symbol={}%3A{}&fields=Recommend.Other%7C1%2CRecommend.All%7C1%2CRecommend.MA%7C1%2CRSI%7C1%2CRSI%5B1%5D%7C1%2CStoch.K%7C1%2CStoch.D%7C1%2CStoch.K%5B1%5D%7C1%2CStoch.D%5B1%5D%7C1%2CCCI20%7C1%2CCCI20%5B1%5D%7C1%2CADX%7C1%2CADX%2BDI%7C1%2CADX-DI%7C1%2CADX%2BDI%5B1%5D%7C1%2CADX-DI%5B1%5D%7C1%2CAO%7C1%2CAO%5B1%5D%7C1%2CAO%5B2%5D%7C1%2CMom%7C1%2CMom%5B1%5D%7C1%2CMACD.macd%7C1%2CMACD.signal%7C1%2CRec.Stoch.RSI%7C1%2CStoch.RSI.K%7C1%2CRec.WR%7C1%2CW.R%7C1%2CRec.BBPower%7C1%2CBBPower%7C1%2CRec.UO%7C1%2CUO%7C1%2CEMA10%7C1%2Cclose%7C1%2CSMA10%7C1%2CEMA20%7C1%2CSMA20%7C1%2CEMA30%7C1%2CSMA30%7C1%2CEMA50%7C1%2CSMA50%7C1%2CEMA100%7C1%2CSMA100%7C1%2CEMA200%7C1%2CSMA200%7C1%2CRec.Ichimoku%7C1%2CIchimoku.BLine%7C1%2CRec.VWMA%7C1%2CVWMA%7C1%2CRec.HullMA9%7C1%2CHullMA9%7C1%2CPivot.M.Classic.S3%7C1%2CPivot.M.Classic.S2%7C1%2CPivot.M.Classic.S1%7C1%2CPivot.M.Classic.Middle%7C1%2CPivot.M.Classic.R1%7C1%2CPivot.M.Classic.R2%7C1%2CPivot.M.Classic.R3%7C1%2CPivot.M.Fibonacci.S3%7C1%2CPivot.M.Fibonacci.S2%7C1%2CPivot.M.Fibonacci.S1%7C1%2CPivot.M.Fibonacci.Middle%7C1%2CPivot.M.Fibonacci.R1%7C1%2CPivot.M.Fibonacci.R2%7C1%2CPivot.M.Fibonacci.R3%7C1%2CPivot.M.Camarilla.S3%7C1%2CPivot.M.Camarilla.S2%7C1%2CPivot.M.Camarilla.S1%7C1%2CPivot.M.Camarilla.Middle%7C1%2CPivot.M.Camarilla.R1%7C1%2CPivot.M.Camarilla.R2%7C1%2CPivot.M.Camarilla.R3%7C1%2CPivot.M.Woodie.S3%7C1%2CPivot.M.Woodie.S2%7C1%2CPivot.M.Woodie.S1%7C1%2CPivot.M.Woodie.Middle%7C1%2CPivot.M.Woodie.R1%7C1%2CPivot.M.Woodie.R2%7C1%2CPivot.M.Woodie.R3%7C1%2CPivot.M.Demark.S1%7C1%2CPivot.M.Demark.Middle%7C1%2CPivot.M.Demark.R1%7C1&no_404=true",
    "5min": "https://scanner.tradingview.com/symbol?symbol={}%3A{}&fields=Recommend.Other%7C5%2CRecommend.All%7C5%2CRecommend.MA%7C5%2CRSI%7C5%2CRSI%5B1%5D%7C5%2CStoch.K%7C5%2CStoch.D%7C5%2CStoch.K%5B1%5D%7C5%2CStoch.D%5B1%5D%7C5%2CCCI20%7C5%2CCCI20%5B1%5D%7C5%2CADX%7C5%2CADX%2BDI%7C5%2CADX-DI%7C5%2CADX%2BDI%5B1%5D%7C5%2CADX-DI%5B1%5D%7C5%2CAO%7C5%2CAO%5B1%5D%7C5%2CAO%5B2%5D%7C5%2CMom%7C5%2CMom%5B1%5D%7C5%2CMACD.macd%7C5%2CMACD.signal%7C5%2CRec.Stoch.RSI%7C5%2CStoch.RSI.K%7C5%2CRec.WR%7C5%2CW.R%7C5%2CRec.BBPower%7C5%2CBBPower%7C5%2CRec.UO%7C5%2CUO%7C5%2CEMA10%7C5%2Cclose%7C5%2CSMA10%7C5%2CEMA20%7C5%2CSMA20%7C5%2CEMA30%7C5%2CSMA30%7C5%2CEMA50%7C5%2CSMA50%7C5%2CEMA100%7C5%2CSMA100%7C5%2CEMA200%7C5%2CSMA200%7C5%2CRec.Ichimoku%7C5%2CIchimoku.BLine%7C5%2CRec.VWMA%7C5%2CVWMA%7C5%2CRec.HullMA9%7C5%2CHullMA9%7C5%2CPivot.M.Classic.S3%7C5%2CPivot.M.Classic.S2%7C5%2CPivot.M.Classic.S1%7C5%2CPivot.M.Classic.Middle%7C5%2CPivot.M.Classic.R1%7C5%2CPivot.M.Classic.R2%7C5%2CPivot.M.Classic.R3%7C5%2CPivot.M.Fibonacci.S3%7C5%2CPivot.M.Fibonacci.S2%7C5%2CPivot.M.Fibonacci.S1%7C5%2CPivot.M.Fibonacci.Middle%7C5%2CPivot.M.Fibonacci.R1%7C5%2CPivot.M.Fibonacci.R2%7C5%2CPivot.M.Fibonacci.R3%7C5%2CPivot.M.Camarilla.S3%7C5%2CPivot.M.Camarilla.S2%7C5%2CPivot.M.Camarilla.S1%7C5%2CPivot.M.Camarilla.Middle%7C5%2CPivot.M.Camarilla.R1%7C5%2CPivot.M.Camarilla.R2%7C5%2CPivot.M.Camarilla.R3%7C5%2CPivot.M.Woodie.S3%7C5%2CPivot.M.Woodie.S2%7C5%2CPivot.M.Woodie.S1%7C5%2CPivot.M.Woodie.Middle%7C5%2CPivot.M.Woodie.R1%7C5%2CPivot.M.Woodie.R2%7C5%2CPivot.M.Woodie.R3%7C5%2CPivot.M.Demark.S1%7C5%2CPivot.M.Demark.Middle%7C5%2CPivot.M.Demark.R1%7C5&no_404=true",
    "15min": "https://scanner.tradingview.com/symbol?symbol={}%3A{}&fields=Recommend.Other%7C15%2CRecommend.All%7C15%2CRecommend.MA%7C15%2CRSI%7C15%2CRSI%5B1%5D%7C15%2CStoch.K%7C15%2CStoch.D%7C15%2CStoch.K%5B1%5D%7C15%2CStoch.D%5B1%5D%7C15%2CCCI20%7C15%2CCCI20%5B1%5D%7C15%2CADX%7C15%2CADX%2BDI%7C15%2CADX-DI%7C15%2CADX%2BDI%5B1%5D%7C15%2CADX-DI%5B1%5D%7C15%2CAO%7C15%2CAO%5B1%5D%7C15%2CAO%5B2%5D%7C15%2CMom%7C15%2CMom%5B1%5D%7C15%2CMACD.macd%7C15%2CMACD.signal%7C15%2CRec.Stoch.RSI%7C15%2CStoch.RSI.K%7C15%2CRec.WR%7C15%2CW.R%7C15%2CRec.BBPower%7C15%2CBBPower%7C15%2CRec.UO%7C15%2CUO%7C15%2CEMA10%7C15%2Cclose%7C15%2CSMA10%7C15%2CEMA20%7C15%2CSMA20%7C15%2CEMA30%7C15%2CSMA30%7C15%2CEMA50%7C15%2CSMA50%7C15%2CEMA100%7C15%2CSMA100%7C15%2CEMA200%7C15%2CSMA200%7C15%2CRec.Ichimoku%7C15%2CIchimoku.BLine%7C15%2CRec.VWMA%7C15%2CVWMA%7C15%2CRec.HullMA9%7C15%2CHullMA9%7C15%2CPivot.M.Classic.S3%7C15%2CPivot.M.Classic.S2%7C15%2CPivot.M.Classic.S1%7C15%2CPivot.M.Classic.Middle%7C15%2CPivot.M.Classic.R1%7C15%2CPivot.M.Classic.R2%7C15%2CPivot.M.Classic.R3%7C15%2CPivot.M.Fibonacci.S3%7C15%2CPivot.M.Fibonacci.S2%7C15%2CPivot.M.Fibonacci.S1%7C15%2CPivot.M.Fibonacci.Middle%7C15%2CPivot.M.Fibonacci.R1%7C15%2CPivot.M.Fibonacci.R2%7C15%2CPivot.M.Fibonacci.R3%7C15%2CPivot.M.Camarilla.S3%7C15%2CPivot.M.Camarilla.S2%7C15%2CPivot.M.Camarilla.S1%7C15%2CPivot.M.Camarilla.Middle%7C15%2CPivot.M.Camarilla.R1%7C15%2CPivot.M.Camarilla.R2%7C15%2CPivot.M.Camarilla.R3%7C15%2CPivot.M.Woodie.S3%7C15%2CPivot.M.Woodie.S2%7C15%2CPivot.M.Woodie.S1%7C15%2CPivot.M.Woodie.Middle%7C15%2CPivot.M.Woodie.R1%7C15%2CPivot.M.Woodie.R2%7C15%2CPivot.M.Woodie.R3%7C15%2CPivot.M.Demark.S1%7C15%2CPivot.M.Demark.Middle%7C15%2CPivot.M.Demark.R1%7C15&no_404=true".format,
    "30min:": "https://scanner.tradingview.com/symbol?symbol={}%3A{}&fields=Recommend.Other%7C30%2CRecommend.All%7C30%2CRecommend.MA%7C30%2CRSI%7C30%2CRSI%5B1%5D%7C30%2CStoch.K%7C30%2CStoch.D%7C30%2CStoch.K%5B1%5D%7C30%2CStoch.D%5B1%5D%7C30%2CCCI20%7C30%2CCCI20%5B1%5D%7C30%2CADX%7C30%2CADX%2BDI%7C30%2CADX-DI%7C30%2CADX%2BDI%5B1%5D%7C30%2CADX-DI%5B1%5D%7C30%2CAO%7C30%2CAO%5B1%5D%7C30%2CAO%5B2%5D%7C30%2CMom%7C30%2CMom%5B1%5D%7C30%2CMACD.macd%7C30%2CMACD.signal%7C30%2CRec.Stoch.RSI%7C30%2CStoch.RSI.K%7C30%2CRec.WR%7C30%2CW.R%7C30%2CRec.BBPower%7C30%2CBBPower%7C30%2CRec.UO%7C30%2CUO%7C30%2CEMA10%7C30%2Cclose%7C30%2CSMA10%7C30%2CEMA20%7C30%2CSMA20%7C30%2CEMA30%7C30%2CSMA30%7C30%2CEMA50%7C30%2CSMA50%7C30%2CEMA100%7C30%2CSMA100%7C30%2CEMA200%7C30%2CSMA200%7C30%2CRec.Ichimoku%7C30%2CIchimoku.BLine%7C30%2CRec.VWMA%7C30%2CVWMA%7C30%2CRec.HullMA9%7C30%2CHullMA9%7C30%2CPivot.M.Classic.S3%7C30%2CPivot.M.Classic.S2%7C30%2CPivot.M.Classic.S1%7C30%2CPivot.M.Classic.Middle%7C30%2CPivot.M.Classic.R1%7C30%2CPivot.M.Classic.R2%7C30%2CPivot.M.Classic.R3%7C30%2CPivot.M.Fibonacci.S3%7C30%2CPivot.M.Fibonacci.S2%7C30%2CPivot.M.Fibonacci.S1%7C30%2CPivot.M.Fibonacci.Middle%7C30%2CPivot.M.Fibonacci.R1%7C30%2CPivot.M.Fibonacci.R2%7C30%2CPivot.M.Fibonacci.R3%7C30%2CPivot.M.Camarilla.S3%7C30%2CPivot.M.Camarilla.S2%7C30%2CPivot.M.Camarilla.S1%7C30%2CPivot.M.Camarilla.Middle%7C30%2CPivot.M.Camarilla.R1%7C30%2CPivot.M.Camarilla.R2%7C30%2CPivot.M.Camarilla.R3%7C30%2CPivot.M.Woodie.S3%7C30%2CPivot.M.Woodie.S2%7C30%2CPivot.M.Woodie.S1%7C30%2CPivot.M.Woodie.Middle%7C30%2CPivot.M.Woodie.R1%7C30%2CPivot.M.Woodie.R2%7C30%2CPivot.M.Woodie.R3%7C30%2CPivot.M.Demark.S1%7C30%2CPivot.M.Demark.Middle%7C30%2CPivot.M.Demark.R1%7C30&no_404=true".format,
    "60min": "https://scanner.tradingview.com/symbol?symbol={}%3A{}&fields=Recommend.Other%7C60%2CRecommend.All%7C60%2CRecommend.MA%7C60%2CRSI%7C60%2CRSI%5B1%5D%7C60%2CStoch.K%7C60%2CStoch.D%7C60%2CStoch.K%5B1%5D%7C60%2CStoch.D%5B1%5D%7C60%2CCCI20%7C60%2CCCI20%5B1%5D%7C60%2CADX%7C60%2CADX%2BDI%7C60%2CADX-DI%7C60%2CADX%2BDI%5B1%5D%7C60%2CADX-DI%5B1%5D%7C60%2CAO%7C60%2CAO%5B1%5D%7C60%2CAO%5B2%5D%7C60%2CMom%7C60%2CMom%5B1%5D%7C60%2CMACD.macd%7C60%2CMACD.signal%7C60%2CRec.Stoch.RSI%7C60%2CStoch.RSI.K%7C60%2CRec.WR%7C60%2CW.R%7C60%2CRec.BBPower%7C60%2CBBPower%7C60%2CRec.UO%7C60%2CUO%7C60%2CEMA10%7C60%2Cclose%7C60%2CSMA10%7C60%2CEMA20%7C60%2CSMA20%7C60%2CEMA30%7C60%2CSMA30%7C60%2CEMA50%7C60%2CSMA50%7C60%2CEMA100%7C60%2CSMA100%7C60%2CEMA200%7C60%2CSMA200%7C60%2CRec.Ichimoku%7C60%2CIchimoku.BLine%7C60%2CRec.VWMA%7C60%2CVWMA%7C60%2CRec.HullMA9%7C60%2CHullMA9%7C60%2CPivot.M.Classic.S3%7C60%2CPivot.M.Classic.S2%7C60%2CPivot.M.Classic.S1%7C60%2CPivot.M.Classic.Middle%7C60%2CPivot.M.Classic.R1%7C60%2CPivot.M.Classic.R2%7C60%2CPivot.M.Classic.R3%7C60%2CPivot.M.Fibonacci.S3%7C60%2CPivot.M.Fibonacci.S2%7C60%2CPivot.M.Fibonacci.S1%7C60%2CPivot.M.Fibonacci.Middle%7C60%2CPivot.M.Fibonacci.R1%7C60%2CPivot.M.Fibonacci.R2%7C60%2CPivot.M.Fibonacci.R3%7C60%2CPivot.M.Camarilla.S3%7C60%2CPivot.M.Camarilla.S2%7C60%2CPivot.M.Camarilla.S1%7C60%2CPivot.M.Camarilla.Middle%7C60%2CPivot.M.Camarilla.R1%7C60%2CPivot.M.Camarilla.R2%7C60%2CPivot.M.Camarilla.R3%7C60%2CPivot.M.Woodie.S3%7C60%2CPivot.M.Woodie.S2%7C60%2CPivot.M.Woodie.S1%7C60%2CPivot.M.Woodie.Middle%7C60%2CPivot.M.Woodie.R1%7C60%2CPivot.M.Woodie.R2%7C60%2CPivot.M.Woodie.R3%7C60%2CPivot.M.Demark.S1%7C60%2CPivot.M.Demark.Middle%7C60%2CPivot.M.Demark.R1%7C60&no_404=true".format,
    "120min": "https://scanner.tradingview.com/symbol?symbol={}%3A{}&fields=Recommend.Other%7C120%2CRecommend.All%7C120%2CRecommend.MA%7C120%2CRSI%7C120%2CRSI%5B1%5D%7C120%2CStoch.K%7C120%2CStoch.D%7C120%2CStoch.K%5B1%5D%7C120%2CStoch.D%5B1%5D%7C120%2CCCI20%7C120%2CCCI20%5B1%5D%7C120%2CADX%7C120%2CADX%2BDI%7C120%2CADX-DI%7C120%2CADX%2BDI%5B1%5D%7C120%2CADX-DI%5B1%5D%7C120%2CAO%7C120%2CAO%5B1%5D%7C120%2CAO%5B2%5D%7C120%2CMom%7C120%2CMom%5B1%5D%7C120%2CMACD.macd%7C120%2CMACD.signal%7C120%2CRec.Stoch.RSI%7C120%2CStoch.RSI.K%7C120%2CRec.WR%7C120%2CW.R%7C120%2CRec.BBPower%7C120%2CBBPower%7C120%2CRec.UO%7C120%2CUO%7C120%2CEMA10%7C120%2Cclose%7C120%2CSMA10%7C120%2CEMA20%7C120%2CSMA20%7C120%2CEMA30%7C120%2CSMA30%7C120%2CEMA50%7C120%2CSMA50%7C120%2CEMA100%7C120%2CSMA100%7C120%2CEMA200%7C120%2CSMA200%7C120%2CRec.Ichimoku%7C120%2CIchimoku.BLine%7C120%2CRec.VWMA%7C120%2CVWMA%7C120%2CRec.HullMA9%7C120%2CHullMA9%7C120%2CPivot.M.Classic.S3%7C120%2CPivot.M.Classic.S2%7C120%2CPivot.M.Classic.S1%7C120%2CPivot.M.Classic.Middle%7C120%2CPivot.M.Classic.R1%7C120%2CPivot.M.Classic.R2%7C120%2CPivot.M.Classic.R3%7C120%2CPivot.M.Fibonacci.S3%7C120%2CPivot.M.Fibonacci.S2%7C120%2CPivot.M.Fibonacci.S1%7C120%2CPivot.M.Fibonacci.Middle%7C120%2CPivot.M.Fibonacci.R1%7C120%2CPivot.M.Fibonacci.R2%7C120%2CPivot.M.Fibonacci.R3%7C120%2CPivot.M.Camarilla.S3%7C120%2CPivot.M.Camarilla.S2%7C120%2CPivot.M.Camarilla.S1%7C120%2CPivot.M.Camarilla.Middle%7C120%2CPivot.M.Camarilla.R1%7C120%2CPivot.M.Camarilla.R2%7C120%2CPivot.M.Camarilla.R3%7C120%2CPivot.M.Woodie.S3%7C120%2CPivot.M.Woodie.S2%7C120%2CPivot.M.Woodie.S1%7C120%2CPivot.M.Woodie.Middle%7C120%2CPivot.M.Woodie.R1%7C120%2CPivot.M.Woodie.R2%7C120%2CPivot.M.Woodie.R3%7C120%2CPivot.M.Demark.S1%7C120%2CPivot.M.Demark.Middle%7C120%2CPivot.M.Demark.R1%7C120&no_404=true".format,
    "240min": "https://scanner.tradingview.com/symbol?symbol={}%3A{}&fields=Recommend.Other%7C240%2CRecommend.All%7C240%2CRecommend.MA%7C240%2CRSI%7C240%2CRSI%5B1%5D%7C240%2CStoch.K%7C240%2CStoch.D%7C240%2CStoch.K%5B1%5D%7C240%2CStoch.D%5B1%5D%7C240%2CCCI20%7C240%2CCCI20%5B1%5D%7C240%2CADX%7C240%2CADX%2BDI%7C240%2CADX-DI%7C240%2CADX%2BDI%5B1%5D%7C240%2CADX-DI%5B1%5D%7C240%2CAO%7C240%2CAO%5B1%5D%7C240%2CAO%5B2%5D%7C240%2CMom%7C240%2CMom%5B1%5D%7C240%2CMACD.macd%7C240%2CMACD.signal%7C240%2CRec.Stoch.RSI%7C240%2CStoch.RSI.K%7C240%2CRec.WR%7C240%2CW.R%7C240%2CRec.BBPower%7C240%2CBBPower%7C240%2CRec.UO%7C240%2CUO%7C240%2CEMA10%7C240%2Cclose%7C240%2CSMA10%7C240%2CEMA20%7C240%2CSMA20%7C240%2CEMA30%7C240%2CSMA30%7C240%2CEMA50%7C240%2CSMA50%7C240%2CEMA100%7C240%2CSMA100%7C240%2CEMA200%7C240%2CSMA200%7C240%2CRec.Ichimoku%7C240%2CIchimoku.BLine%7C240%2CRec.VWMA%7C240%2CVWMA%7C240%2CRec.HullMA9%7C240%2CHullMA9%7C240%2CPivot.M.Classic.S3%7C240%2CPivot.M.Classic.S2%7C240%2CPivot.M.Classic.S1%7C240%2CPivot.M.Classic.Middle%7C240%2CPivot.M.Classic.R1%7C240%2CPivot.M.Classic.R2%7C240%2CPivot.M.Classic.R3%7C240%2CPivot.M.Fibonacci.S3%7C240%2CPivot.M.Fibonacci.S2%7C240%2CPivot.M.Fibonacci.S1%7C240%2CPivot.M.Fibonacci.Middle%7C240%2CPivot.M.Fibonacci.R1%7C240%2CPivot.M.Fibonacci.R2%7C240%2CPivot.M.Fibonacci.R3%7C240%2CPivot.M.Camarilla.S3%7C240%2CPivot.M.Camarilla.S2%7C240%2CPivot.M.Camarilla.S1%7C240%2CPivot.M.Camarilla.Middle%7C240%2CPivot.M.Camarilla.R1%7C240%2CPivot.M.Camarilla.R2%7C240%2CPivot.M.Camarilla.R3%7C240%2CPivot.M.Woodie.S3%7C240%2CPivot.M.Woodie.S2%7C240%2CPivot.M.Woodie.S1%7C240%2CPivot.M.Woodie.Middle%7C240%2CPivot.M.Woodie.R1%7C240%2CPivot.M.Woodie.R2%7C240%2CPivot.M.Woodie.R3%7C240%2CPivot.M.Demark.S1%7C240%2CPivot.M.Demark.Middle%7C240%2CPivot.M.Demark.R1%7C240&no_404=true".format,
    "1day": "https://scanner.tradingview.com/symbol?symbol={}%3A{}&fields=Recommend.Other%2CRecommend.All%2CRecommend.MA%2CRSI%2CRSI%5B1%5D%2CStoch.K%2CStoch.D%2CStoch.K%5B1%5D%2CStoch.D%5B1%5D%2CCCI20%2CCCI20%5B1%5D%2CADX%2CADX%2BDI%2CADX-DI%2CADX%2BDI%5B1%5D%2CADX-DI%5B1%5D%2CAO%2CAO%5B1%5D%2CAO%5B2%5D%2CMom%2CMom%5B1%5D%2CMACD.macd%2CMACD.signal%2CRec.Stoch.RSI%2CStoch.RSI.K%2CRec.WR%2CW.R%2CRec.BBPower%2CBBPower%2CRec.UO%2CUO%2CEMA10%2Cclose%2CSMA10%2CEMA20%2CSMA20%2CEMA30%2CSMA30%2CEMA50%2CSMA50%2CEMA100%2CSMA100%2CEMA200%2CSMA200%2CRec.Ichimoku%2CIchimoku.BLine%2CRec.VWMA%2CVWMA%2CRec.HullMA9%2CHullMA9%2CPivot.M.Classic.S3%2CPivot.M.Classic.S2%2CPivot.M.Classic.S1%2CPivot.M.Classic.Middle%2CPivot.M.Classic.R1%2CPivot.M.Classic.R2%2CPivot.M.Classic.R3%2CPivot.M.Fibonacci.S3%2CPivot.M.Fibonacci.S2%2CPivot.M.Fibonacci.S1%2CPivot.M.Fibonacci.Middle%2CPivot.M.Fibonacci.R1%2CPivot.M.Fibonacci.R2%2CPivot.M.Fibonacci.R3%2CPivot.M.Camarilla.S3%2CPivot.M.Camarilla.S2%2CPivot.M.Camarilla.S1%2CPivot.M.Camarilla.Middle%2CPivot.M.Camarilla.R1%2CPivot.M.Camarilla.R2%2CPivot.M.Camarilla.R3%2CPivot.M.Woodie.S3%2CPivot.M.Woodie.S2%2CPivot.M.Woodie.S1%2CPivot.M.Woodie.Middle%2CPivot.M.Woodie.R1%2CPivot.M.Woodie.R2%2CPivot.M.Woodie.R3%2CPivot.M.Demark.S1%2CPivot.M.Demark.Middle%2CPivot.M.Demark.R1&no_404=true".format,
    "1week": "https://scanner.tradingview.com/symbol?symbol={}%3A{}&fields=Recommend.Other%7C1W%2CRecommend.All%7C1W%2CRecommend.MA%7C1W%2CRSI%7C1W%2CRSI%5B1%5D%7C1W%2CStoch.K%7C1W%2CStoch.D%7C1W%2CStoch.K%5B1%5D%7C1W%2CStoch.D%5B1%5D%7C1W%2CCCI20%7C1W%2CCCI20%5B1%5D%7C1W%2CADX%7C1W%2CADX%2BDI%7C1W%2CADX-DI%7C1W%2CADX%2BDI%5B1%5D%7C1W%2CADX-DI%5B1%5D%7C1W%2CAO%7C1W%2CAO%5B1%5D%7C1W%2CAO%5B2%5D%7C1W%2CMom%7C1W%2CMom%5B1%5D%7C1W%2CMACD.macd%7C1W%2CMACD.signal%7C1W%2CRec.Stoch.RSI%7C1W%2CStoch.RSI.K%7C1W%2CRec.WR%7C1W%2CW.R%7C1W%2CRec.BBPower%7C1W%2CBBPower%7C1W%2CRec.UO%7C1W%2CUO%7C1W%2CEMA10%7C1W%2Cclose%7C1W%2CSMA10%7C1W%2CEMA20%7C1W%2CSMA20%7C1W%2CEMA30%7C1W%2CSMA30%7C1W%2CEMA50%7C1W%2CSMA50%7C1W%2CEMA100%7C1W%2CSMA100%7C1W%2CEMA200%7C1W%2CSMA200%7C1W%2CRec.Ichimoku%7C1W%2CIchimoku.BLine%7C1W%2CRec.VWMA%7C1W%2CVWMA%7C1W%2CRec.HullMA9%7C1W%2CHullMA9%7C1W%2CPivot.M.Classic.S3%7C1W%2CPivot.M.Classic.S2%7C1W%2CPivot.M.Classic.S1%7C1W%2CPivot.M.Classic.Middle%7C1W%2CPivot.M.Classic.R1%7C1W%2CPivot.M.Classic.R2%7C1W%2CPivot.M.Classic.R3%7C1W%2CPivot.M.Fibonacci.S3%7C1W%2CPivot.M.Fibonacci.S2%7C1W%2CPivot.M.Fibonacci.S1%7C1W%2CPivot.M.Fibonacci.Middle%7C1W%2CPivot.M.Fibonacci.R1%7C1W%2CPivot.M.Fibonacci.R2%7C1W%2CPivot.M.Fibonacci.R3%7C1W%2CPivot.M.Camarilla.S3%7C1W%2CPivot.M.Camarilla.S2%7C1W%2CPivot.M.Camarilla.S1%7C1W%2CPivot.M.Camarilla.Middle%7C1W%2CPivot.M.Camarilla.R1%7C1W%2CPivot.M.Camarilla.R2%7C1W%2CPivot.M.Camarilla.R3%7C1W%2CPivot.M.Woodie.S3%7C1W%2CPivot.M.Woodie.S2%7C1W%2CPivot.M.Woodie.S1%7C1W%2CPivot.M.Woodie.Middle%7C1W%2CPivot.M.Woodie.R1%7C1W%2CPivot.M.Woodie.R2%7C1W%2CPivot.M.Woodie.R3%7C1W%2CPivot.M.Demark.S1%7C1W%2CPivot.M.Demark.Middle%7C1W%2CPivot.M.Demark.R1%7C1W&no_404=true".format,
    "1month": "https://scanner.tradingview.com/symbol?symbol={}%3A{}&fields=Recommend.Other%7C1M%2CRecommend.All%7C1M%2CRecommend.MA%7C1M%2CRSI%7C1M%2CRSI%5B1%5D%7C1M%2CStoch.K%7C1M%2CStoch.D%7C1M%2CStoch.K%5B1%5D%7C1M%2CStoch.D%5B1%5D%7C1M%2CCCI20%7C1M%2CCCI20%5B1%5D%7C1M%2CADX%7C1M%2CADX%2BDI%7C1M%2CADX-DI%7C1M%2CADX%2BDI%5B1%5D%7C1M%2CADX-DI%5B1%5D%7C1M%2CAO%7C1M%2CAO%5B1%5D%7C1M%2CAO%5B2%5D%7C1M%2CMom%7C1M%2CMom%5B1%5D%7C1M%2CMACD.macd%7C1M%2CMACD.signal%7C1M%2CRec.Stoch.RSI%7C1M%2CStoch.RSI.K%7C1M%2CRec.WR%7C1M%2CW.R%7C1M%2CRec.BBPower%7C1M%2CBBPower%7C1M%2CRec.UO%7C1M%2CUO%7C1M%2CEMA10%7C1M%2Cclose%7C1M%2CSMA10%7C1M%2CEMA20%7C1M%2CSMA20%7C1M%2CEMA30%7C1M%2CSMA30%7C1M%2CEMA50%7C1M%2CSMA50%7C1M%2CEMA100%7C1M%2CSMA100%7C1M%2CEMA200%7C1M%2CSMA200%7C1M%2CRec.Ichimoku%7C1M%2CIchimoku.BLine%7C1M%2CRec.VWMA%7C1M%2CVWMA%7C1M%2CRec.HullMA9%7C1M%2CHullMA9%7C1M%2CPivot.M.Classic.S3%7C1M%2CPivot.M.Classic.S2%7C1M%2CPivot.M.Classic.S1%7C1M%2CPivot.M.Classic.Middle%7C1M%2CPivot.M.Classic.R1%7C1M%2CPivot.M.Classic.R2%7C1M%2CPivot.M.Classic.R3%7C1M%2CPivot.M.Fibonacci.S3%7C1M%2CPivot.M.Fibonacci.S2%7C1M%2CPivot.M.Fibonacci.S1%7C1M%2CPivot.M.Fibonacci.Middle%7C1M%2CPivot.M.Fibonacci.R1%7C1M%2CPivot.M.Fibonacci.R2%7C1M%2CPivot.M.Fibonacci.R3%7C1M%2CPivot.M.Camarilla.S3%7C1M%2CPivot.M.Camarilla.S2%7C1M%2CPivot.M.Camarilla.S1%7C1M%2CPivot.M.Camarilla.Middle%7C1M%2CPivot.M.Camarilla.R1%7C1M%2CPivot.M.Camarilla.R2%7C1M%2CPivot.M.Camarilla.R3%7C1M%2CPivot.M.Woodie.S3%7C1M%2CPivot.M.Woodie.S2%7C1M%2CPivot.M.Woodie.S1%7C1M%2CPivot.M.Woodie.Middle%7C1M%2CPivot.M.Woodie.R1%7C1M%2CPivot.M.Woodie.R2%7C1M%2CPivot.M.Woodie.R3%7C1M%2CPivot.M.Demark.S1%7C1M%2CPivot.M.Demark.Middle%7C1M%2CPivot.M.Demark.R1%7C1M&no_404=true".format,
}
